==> aws-cdk.aws-iot-actions-1.142.0.tar.gz: package/lib/cloudwatch-put-metric-action.d.ts <==
import * as iot from '@aws-cdk/aws-iot';
import { CommonActionProps } from './common-action-props';
/**
 * (experimental) Configuration properties of an action for CloudWatch metric.
 *
 * @experimental
 */
export interface CloudWatchPutMetricActionProps extends CommonActionProps {
    /**
     * (experimental) The CloudWatch metric name.
     *
     * Supports substitution templates.
     *
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     * @experimental
     */
    readonly metricName: string;
    /**
     * (experimental) The CloudWatch metric namespace name.
     *
     * Supports substitution templates.
     *
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     * @experimental
     */
    readonly metricNamespace: string;
    /**
     * (experimental) A string that contains the timestamp, expressed in seconds in Unix epoch time.
     *
     * Supports substitution templates.
     *
     * @default - none -- Defaults to the current Unix epoch time.
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     * @experimental
     */
    readonly metricTimestamp?: string;
    /**
     * (experimental) The metric unit supported by CloudWatch.
     *
     * Supports substitution templates.
     *
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     * @experimental
     */
    readonly metricUnit: string;
    /**
     * (experimental) A string that contains the CloudWatch metric value.
     *
     * Supports substitution templates.
     *
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     * @experimental
     */
    readonly metricValue: string;
}
/**
 * (experimental) The action to capture an Amazon CloudWatch metric.
 *
 * @experimental
 */
export declare class CloudWatchPutMetricAction implements iot.IAction {
    private readonly props;
    /**
     * @experimental
     */
    constructor(props: CloudWatchPutMetricActionProps);
    /**
     * (experimental) (experimental) Returns the topic rule action specification.
     *
     * @experimental
     */
    bind(rule: iot.ITopicRule): iot.ActionConfig;
}

==> aws-cdk.aws-iot-actions-1.173.0.tar.gz: package/lib/cloudwatch-put-metric-action.d.ts <==
import * as iot from '@aws-cdk/aws-iot';
import { CommonActionProps } from './common-action-props';
/**
 * Configuration properties of an action for CloudWatch metric.
 */
export interface CloudWatchPutMetricActionProps extends CommonActionProps {
    /**
     * The CloudWatch metric name.
     *
     * Supports substitution templates.
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     */
    readonly metricName: string;
    /**
     * The CloudWatch metric namespace name.
     *
     * Supports substitution templates.
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     */
    readonly metricNamespace: string;
    /**
     * A string that contains the timestamp, expressed in seconds in Unix epoch time.
     *
     * Supports substitution templates.
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     *
     * @default - none -- Defaults to the current Unix epoch time.
     */
    readonly metricTimestamp?: string;
    /**
     * The metric unit supported by CloudWatch.
     *
     * Supports substitution templates.
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     */
    readonly metricUnit: string;
    /**
     * A string that contains the CloudWatch metric value.
     *
     * Supports substitution templates.
     * @see https://docs.aws.amazon.com/iot/latest/developerguide/iot-substitution-templates.html
     */
    readonly metricValue: string;
}
/**
 * The action to capture an Amazon CloudWatch metric.
 */
export declare class CloudWatchPutMetricAction implements iot.IAction {
    private readonly props;
    constructor(props: CloudWatchPutMetricActionProps);
    bind(rule: iot.ITopicRule): iot.ActionConfig;
}
